package com.chelvc.cloud.vehicle.client;

import com.chelvc.cloud.vehicle.client.dto.AttentionTotalDTO;
import com.chelvc.cloud.vehicle.client.dto.AttentionUserDTO;
import com.chelvc.cloud.vehicle.client.param.QueryAttentionParam;
import com.chelvc.framework.common.model.Pagination;
import com.chelvc.framework.common.model.Paging;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.web.bind.annotation.GetMapping;

import java.util.List;
import java.util.Map;

/**
 * @author: igl
 * @date: 2023/8/14 10:11
 */
@FeignClient("vehicle")
public interface AttentionClient {

  /**
   * 关注用户
   * @param userId
   * @param targetUserId
   */
  @GetMapping("/attention/concern")
  void concern(Long userId, Long targetUserId);

  /**
   * 分页查看关注、粉丝、好友
   *
   * @param page
   * @param param
   * @author igl
   * @date 2023/2/25 19:42
   */
  @GetMapping("/attention/page")
  Pagination<AttentionUserDTO> page(Paging page, QueryAttentionParam param, Long userId);

  /**
   * 查询用户是否关注
   * @param userId
   * @param userIds
   * @return
   */
  @GetMapping("/attention/queryAttentionByUserIds")
  Map<Long, Boolean> queryAttentionByUserIds(Long userId, List<Long> userIds);

  /**
   * 查看关注、粉丝、好友总数
   * @author igl
   * @date 2023/8/15 19:42
   */
  @GetMapping("/attention/queryTotalByUserId")
  AttentionTotalDTO queryTotalByUserId(Long userId);
}
