package com.chelvc.cloud.vehicle.client;

import com.chelvc.cloud.vehicle.client.dto.CarouselImagesDTO;
import com.chelvc.cloud.vehicle.client.param.CarouselImagesModifyParam;
import com.chelvc.cloud.vehicle.client.param.CarouselImagesPagingParam;
import com.chelvc.framework.common.model.Pagination;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 * 轮播图接口
 *
 * @author liude
 * @data 2023/12/31
 */
@FeignClient("vehicle")
public interface CarouselImagesClient {

    /**
     * 新增轮播图
     *
     * @param param 新增参数
     * @return 轮播图主键
     */
    @PostMapping("/carouselImages/addCarouselImages")
    Long addCarouselImages(@RequestBody CarouselImagesModifyParam param);

    /**
     * 修改轮播图
     *
     * @param id    轮播图主键
     * @param param 修改参数
     */
    @GetMapping("/carouselImages/updateCarouselImages")
    void updateCarouselImages(Long id, CarouselImagesModifyParam param);

    /**
     * 查询轮播图
     *
     * @param param 查询参数
     * @return 轮播图分页信息
     */
    @GetMapping("/carouselImages/getCarouselImagesPaging")
    Pagination<CarouselImagesDTO> getCarouselImagesPaging(CarouselImagesPagingParam param);

    /**
     * 删除轮播图
     *
     * @param id    轮播图主键
     */
    @DeleteMapping("/carouselImages/{id}")
    void deleteCarouselImages(@PathVariable Long id);

    /**
     * 轮播图列表
     * @return
     */
    @GetMapping("/carouselImages/listCarouselImages")
    List<CarouselImagesDTO> listCarouselImages();
}
