package com.chelvc.cloud.vehicle.client;

import com.chelvc.cloud.vehicle.client.dto.CategoryDTO;
import com.chelvc.cloud.vehicle.client.param.CategoryListParam;
import com.chelvc.cloud.vehicle.client.param.CategoryModifyParam;
import com.chelvc.cloud.vehicle.client.param.CategoryPagingParam;
import com.chelvc.framework.common.model.Pagination;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 * 分类业务操作接口
 *
 * @author Woody
 * @date 2023/5/2
 */
@FeignClient("vehicle")
public interface CategoryClient {
    /**
     * 新增分类
     *
     * @param param 新增参数
     * @return 分类主键
     */
    @PostMapping("/category/addCategory")
    Long addCategory(@RequestBody CategoryModifyParam param);

    /**
     * 修改分类
     *
     * @param id    分类主键
     * @param param 修改参数
     */
    @GetMapping("/category/updateCategory")
    void updateCategory(Long id, CategoryModifyParam param);

    /**
     * 查询分类
     *
     * @param param 查询参数
     * @return 分类分页信息
     */
    @GetMapping("/category/getCategoryPaging")
    Pagination<CategoryDTO> getCategoryPaging(CategoryPagingParam param);

    /**
     * 获取有效分类信息
     *
     * @return 分类信息列表
     */
    @GetMapping("/category/listActiveCategories")
    List<CategoryDTO> listActiveCategories(CategoryListParam param);

    /**
     * 获取有效分类信息
     *
     * @return 分类信息列表
     */
    @GetMapping("/category/listCategory")
    List<CategoryDTO> listCategory(CategoryListParam param);

    /**
     * 获取推荐分类信息
     *
     * @param size 分类个数
     * @return 分类信息列表
     */
    @GetMapping("/category/listRecommendCategories")
    List<CategoryDTO> listRecommendCategories(int size);


    /**
     * 删除分类
     *
     * @param id    分类主键
     */
    @DeleteMapping("/category/{id}")
    void deleteCategory(@PathVariable Long id);

    /**
     * 获取分类列表
     * @return 分类信息
     */
    @GetMapping("/category/getRootCategories")
    List<CategoryDTO> getRootCategories(CategoryListParam param);

    /**
     * 获取一级分类
     * @return 分类信息
     */
    @GetMapping("/category/getParentCategories")
    List<CategoryDTO> getParentCategories(CategoryListParam param);
}
