package com.chelvc.cloud.vehicle.client;

import com.chelvc.cloud.vehicle.client.dto.CommissionConfigDTO;
import com.chelvc.cloud.vehicle.client.param.CommissionConfigModifyParam;
import com.chelvc.cloud.vehicle.client.param.CommissionConfigPagingParam;
import com.chelvc.framework.common.model.Pagination;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 * 邀请别人消费，邀请人数的不同抽成配置接口
 *
 * @author liude
 * @data 2023/12/31
 */
@FeignClient("vehicle")
public interface CommissionConfigClient {

    /**
     * 新增抽成配置
     *
     * @param param 新增参数
     * @return 抽成配置主键
     */
    @PostMapping("/commissionConfig/addCommissionConfig")
    Long addCommissionConfig(@RequestBody CommissionConfigModifyParam param);

    /**
     * 修改抽成配置
     *
     * @param id    抽成配置主键
     * @param param 修改参数
     */
    @GetMapping("/commissionConfig/updateCommissionConfig")
    void updateCommissionConfig(Long id, CommissionConfigModifyParam param);

    /**
     * 查询抽成配置
     *
     * @param param 查询参数
     * @return 抽成配置分页信息
     */
    @GetMapping("/commissionConfig/getCommissionConfigPaging")
    Pagination<CommissionConfigDTO> getCommissionConfigPaging(CommissionConfigPagingParam param);

    /**
     * 删除抽成配置
     *
     * @param id    抽成配置主键
     */
    @DeleteMapping("/commissionConfig/{id}")
    void deleteCommissionConfig(@PathVariable Long id);

    /**
     * 分佣配置列表
     * @return
     */
    @GetMapping("/commissionConfig/listCommissionConfig")
    List<CommissionConfigDTO> listCommissionConfig();

}
