package com.chelvc.cloud.vehicle.client;

import com.chelvc.cloud.vehicle.client.dto.CouponDTO;
import com.chelvc.cloud.vehicle.client.param.CouponModifyParam;
import com.chelvc.cloud.vehicle.client.param.CouponPagingParam;
import com.chelvc.framework.common.model.Pagination;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.web.bind.annotation.*;

/**
 * 优惠券业务接口
 *
 * @author qizai
 * @date 2023/9/8
 */
@FeignClient("vehicle")
public interface CouponClient {
    /**
     * 新增优惠券
     *
     * @param param 新增参数
     * @return 优惠券主键
     */
    @PostMapping("/coupon/addCoupon")
    Long addCoupon(@RequestBody CouponModifyParam param);

    /**
     * 修改优惠券
     *
     * @param id    优惠券主键
     * @param param 修改参数
     */
    @GetMapping("/coupon/updateCoupon")
    void updateCoupon(Long id, CouponModifyParam param);

    /**
     * 删除商品优惠券
     *
     * @param id    商品优惠券主键
     */
    @DeleteMapping("/coupon/{id}")
    void deleteCoupon(@PathVariable Long id);

    /**
     * 获取优惠券信息
     *
     * @param id 优惠券主键
     * @return 优惠券信息
     */
    @GetMapping("/coupon/getCoupon")
    CouponDTO getCoupon(Long id);

    /**
     * 查询优惠券信息
     *
     * @param param 查询参数
     * @return 优惠券分页信息
     */
    @GetMapping("/coupon/getCouponPaging")
    Pagination<CouponDTO> getCouponPaging(CouponPagingParam param);

    /**
     * 查询优惠券信息
     *
     * @param merchantId 商家ID
     * @param param 分页参数
     * @return 优惠券分页信息
     */
    @GetMapping("/coupon/getMerchantCouponPaging")
    Pagination<CouponDTO> getMerchantCouponPaging(Long merchantId, CouponPagingParam param);
}
