package com.chelvc.cloud.vehicle.client;


import com.chelvc.cloud.vehicle.client.constant.ExamineType;
import com.chelvc.cloud.vehicle.client.dto.DynamicCommentDTO;
import com.chelvc.cloud.vehicle.client.param.AddDynamicCommentParam;
import com.chelvc.cloud.vehicle.client.param.QueryAdminDynamicParam;
import com.chelvc.cloud.vehicle.client.param.QueryDynamicCommentParam;
import com.chelvc.framework.common.model.Pagination;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.web.bind.annotation.GetMapping;

/**
 * 动态评论Service接口
 *
 * @author igl
 * @date 2023-02-25
 */
@FeignClient("vehicle")
public interface DynamicCommentClient {

    /**
     * 查询动态评论列表
     */
    @GetMapping("/dynamicComment/queryPageList")
    Pagination<DynamicCommentDTO> queryPageList(QueryDynamicCommentParam param, Integer pageNum, Integer pageSize);

    /**
     * 查询动态信息列表
     */
    @GetMapping("/dynamicComment/queryAdminPageList")
    Pagination<DynamicCommentDTO> queryAdminPageList(QueryAdminDynamicParam param);

    /**
     * 修改动态评论
     */
    @GetMapping("/dynamicComment/insertByBo")
    void insertByBo(AddDynamicCommentParam param, Long userId);

    /**
     * 给评论添加点赞/踩
     * @param dynamicStatus
     * @param contentId
     */
    @GetMapping("/dynamicComment/addNum")
    void addNum(Integer dynamicStatus, Long contentId);

    /**
     * 取消评论点赞/踩
     * @param dynamicStatus
     * @param contentId
     */
    @GetMapping("/dynamicComment/reduceNum")
    void reduceNum(Integer dynamicStatus, Long contentId);

    /**
     * 评论手动审核
     *
     * @param id
     * @param examine
     * @author igl
     * @date 2023/8/17 17:25
     */
    @GetMapping("/dynamicComment/examine")
    void examine(Long id, ExamineType examine);

    /**
     * 自动审核
     *
     * @param id 评论标识
     * @param platformStatus 平台状态
     * @param examineResult 审核结果
     * @author igl
     * @date 2023/9/12 17:25
     */
    @GetMapping("/dynamicComment/autoAudit")
    void autoAudit(Long id, int platformStatus, int examineResult);
}
