package com.chelvc.cloud.vehicle.client;

import com.chelvc.cloud.vehicle.client.constant.ExamineType;
import com.chelvc.cloud.vehicle.client.dto.DynamicContentDTO;
import com.chelvc.cloud.vehicle.client.param.AddDynamicContentParam;
import com.chelvc.cloud.vehicle.client.param.QueryAdminDynamicParam;
import com.chelvc.cloud.vehicle.client.param.QueryDynamicContentParam;
import com.chelvc.framework.common.model.Pagination;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;

import java.util.Map;

/**
 * 动态信息Service接口
 *
 * @USER: igl
 * @date: 2023/8/8 15:13
 */
@FeignClient("vehicle")
public interface DynamicContentClient {

  /**
   * 查询动态信息
   */
  @GetMapping("/dynamicContent/queryById")
  DynamicContentDTO queryById(Long id, Long userId);

  /**
   * 查询动态信息列表
   */
  @GetMapping("/dynamicContent/queryPageList")
  Pagination<DynamicContentDTO> queryPageList(QueryDynamicContentParam param, Integer pageNum,
                                              Integer pageSize, Long userId);

  /**
   * 查询动态信息列表
   */
  @GetMapping("/dynamicContent/queryAdminPageList")
  Pagination<DynamicContentDTO> queryAdminPageList(QueryAdminDynamicParam param);

  /**
   * 查询动态信息列表
   */
  @GetMapping("/dynamicContent/queryUserById")
  Pagination<DynamicContentDTO> queryUserById(Long selfUserId, Long userId, Integer pageNum, Integer pageSize);

  /**
   * 修改动态信息
   */
  @GetMapping("/dynamicContent/insertByBo")
  void insertByBo(AddDynamicContentParam dto, Long userId);

  /**
   * 校验并批量删除动态信息信息
   */
  @DeleteMapping("/dynamicContent/{id}/{userId}")
  void deleteByIds(@PathVariable Long id, @PathVariable Long userId);

  /**
   * 添加评论数
   *
   * @param dynamicId
   */
  @GetMapping("/dynamicContent/addComment")
  void addComment(Long dynamicId);

  /**
   * 减少评论数
   *
   * @param dynamicId
   */
  @GetMapping("/dynamicContent/reduceComment")
  void reduceComment(Long dynamicId, int num);

  /**
   * 给评论添加点赞/踩
   *
   * @param dynamicStatus
   * @param contentId
   */
  @GetMapping("/dynamicContent/addNum")
  void addNum(Integer dynamicStatus, Long contentId);

  /**
   * 取消评论点赞/踩
   *
   * @param dynamicStatus
   * @param contentId
   */
  @GetMapping("/dynamicContent/reduceNum")
  void reduceNum(Integer dynamicStatus, Long contentId);

  /**
   * 屏蔽/恢复某条动态信息
   *
   * @param id 主键
   */
  @GetMapping("/dynamicContent/shieldById")
  void shieldById(Long id, Integer type);

  /**
   * 屏蔽/恢复某个用户所有动态信息
   *
   * @param userId 主键
   * @param type   状态 0-正常；1-平台屏蔽
   */
  @GetMapping("/dynamicContent/shieldByUserId")
  void shieldByUserId(Long userId, Integer type);

  /**
   * 动态手动审核
   *
   * @param id
   * @param examine
   * @author igl
   * @date 2023/8/17 17:25
   */
  @GetMapping("/dynamicContent/examine")
  void examine(Long id, ExamineType examine);

  /**
   * 自动审核
   *
   * @param id 动态标识
   * @param platformStatus 平台状态
   * @param examineResult 审核结果
   * @author igl
   * @date 2023/9/12 17:25
   */
  @GetMapping("/dynamicContent/autoAudit")
  void autoAudit(Long id, int platformStatus, int examineResult);

  /**
   * 视频审核回调
   *
   * @param param
   * @author igl
   * @date 2023/9/12 16:55
   */
  @GetMapping("/dynamicContent/videoAuditCallback")
  void videoAuditCallback(Map<String, Object> param);
}
