package com.chelvc.cloud.vehicle.client;

import com.chelvc.cloud.vehicle.client.dto.FavoriteDTO;
import com.chelvc.cloud.vehicle.client.dto.MerchantDTO;
import com.chelvc.cloud.vehicle.client.param.FavoritePagingParam;
import com.chelvc.cloud.vehicle.client.param.FavoriteQueryParam;
import com.chelvc.framework.common.model.Pagination;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;

import java.util.List;

/**
 * 商品收藏接口
 *
 * @author liude
 * @date 2023/7/18
 */
@FeignClient("vehicle")
public interface FavoriteClient {
    /**
     * 收藏商家
     *
     * @param merchantId 商家ID
     * @return 收藏ID
     */
    @GetMapping("/favorite/addMerchantFavorite")
    Long addMerchantFavorite(Long merchantId,String type);

    /**
     * 取消我的收藏
     *
     * @param id 收藏ID
     */
    @DeleteMapping("/favorite/{id}")
    void deleteMineFavorite(@PathVariable Long id);

    /**
     * 查询收藏列表
     *
     * @param param 查询参数
     * @return 收藏店铺分页信息
     */
    @GetMapping("/favorite/getFavoriteMerchantPaging")
    Pagination<MerchantDTO> getFavoriteMerchantPaging(FavoritePagingParam param);

    /**
     * 查询用户收藏店铺列表
     *
     * @param param 查询参数
     * @return 用户收藏店铺列表
     */
    @GetMapping("/favorite/listFavoriteMerchants")
    List<FavoriteDTO> listFavoriteMerchants(FavoriteQueryParam param);

    /**
     * 查询用户收藏商品列表
     * @return 用户收藏商品列表
     */
    @GetMapping("/favorite/listFavoriteGoods")
    List<FavoriteDTO> listFavoriteGoods();
}
