package com.chelvc.cloud.vehicle.client;

import com.chelvc.cloud.vehicle.client.dto.FeedBackDTO;
import com.chelvc.cloud.vehicle.client.param.FeedBackModifyParam;
import com.chelvc.cloud.vehicle.client.param.FeedBackPagingParam;
import com.chelvc.framework.common.model.Pagination;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;

import java.util.List;

/**
 * 意见反馈接口
 *
 * @author liude
 * @data 2024/1/12
 */
@FeignClient("vehicle")
public interface FeedbackClient {

    /**
     * 新增意见反馈
     *
     * @param param 新增参数
     * @return 主键
     */
    @PostMapping("/feedback/addFeedback")
    Long addFeedback(@RequestBody FeedBackModifyParam param);

    /**
     * 修改意见反馈
     *
     * @param id    主键
     * @param param 修改参数
     */
    @GetMapping("/feedback/updateFeedback")
    void updateFeedback(Long id, FeedBackModifyParam param);

    /**
     * 获取意见反馈信息
     * @return
     */
    @GetMapping("/feedback/getFeedback")
    List<FeedBackDTO> getFeedback(String channel);

    /**
     * 意见反馈分页查询
     * @param param
     * @return
     */
    @GetMapping("/feedback/getFeedbackPaging")
    Pagination<FeedBackDTO> getFeedbackPaging(FeedBackPagingParam param);

    /**
     * 更新意见反馈状态
     * @param id
     * @param status
     */
    @GetMapping("/feedback/updateStatus")
    void updateStatus(Long id,String status);
}
