package com.chelvc.cloud.vehicle.client;

import com.chelvc.cloud.vehicle.client.dto.HelpCategoryDTO;
import com.chelvc.cloud.vehicle.client.param.HelpCategoryModifyParam;
import com.chelvc.cloud.vehicle.client.param.HelpCategoryPagingParam;
import com.chelvc.framework.common.model.Pagination;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;

import java.util.List;

/**
 * 帮助分类Service接口
 *
 * @author liude
 * @date 2023-11-08
 */
@FeignClient("vehicle")
public interface HelpCategoryClient
{
    /**
     * 查询帮助分类
     *
     * @param id 帮助分类主键
     * @return 帮助分类
     */
    @GetMapping("/helpCategory/selectHelpCategoryById")
    public HelpCategoryDTO selectHelpCategoryById(Long id);

    /**
     * 查询帮助分类列表
     *
     * @param helpCategory 帮助分类
     * @return 帮助分类集合
     */
    @GetMapping("/helpCategory/selectHelpCategoryList")
    public List<HelpCategoryDTO> selectHelpCategoryList(HelpCategoryModifyParam helpCategory);

    /**
     * 新增帮助分类
     *
     * @param helpCategory 帮助分类
     * @return 结果
     */
    @GetMapping("/helpCategory/insertHelpCategory")
    public void insertHelpCategory(@RequestBody HelpCategoryModifyParam helpCategory);

    /**
     * 修改帮助分类
     *
     * @param helpCategory 帮助分类
     * @return 结果
     */
    @GetMapping("/helpCategory/updateHelpCategory")
    public void updateHelpCategory(Long id,HelpCategoryModifyParam helpCategory);


    /**
     * 删除帮助分类信息
     *
     * @param id 帮助分类主键
     * @return 结果
     */
    @DeleteMapping("/helpCategory/{id}")
    public void deleteHelpCategoryById(@PathVariable Long id);

    /**
     * 分页查询帮助分类列表
     * @param param
     * @return
     */
    @GetMapping("/helpCategory/getHelpCategoryPaging")
    Pagination<HelpCategoryDTO> getHelpCategoryPaging(HelpCategoryPagingParam param);


    /**
     * 查询帮助分类列表
     *
     * @return 帮助分类集合
     */
    @GetMapping("/helpCategory/selectHelpCategories")
    public List<HelpCategoryDTO> selectHelpCategories();
}
