package com.chelvc.cloud.vehicle.client;

import com.chelvc.cloud.vehicle.client.dto.HelpDTO;
import com.chelvc.cloud.vehicle.client.param.HelpModifyParam;
import com.chelvc.cloud.vehicle.client.param.HelpPagingParam;
import com.chelvc.framework.common.model.Pagination;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 * 帮助Service接口
 *
 * @author liude
 * @date 2023-11-08
 */
@FeignClient("vehicle")
public interface HelpClient
{
    /**
     * 查询帮助
     *
     * @param id 帮助主键
     * @return 帮助
     */
    @GetMapping("/help/selectHelpById")
    public HelpDTO selectHelpById(Long id);

    /**
     * 查询帮助列表
     *
     * @param param 帮助
     * @return 帮助集合
     */
    @GetMapping("/help/selectHelpList")
    public List<HelpDTO> selectHelpList(HelpModifyParam param);

    /**
     * 新增帮助
     *
     * @param param 帮助
     * @return 结果
     */
    @PostMapping("/help/insertHelp")
    public void insertHelp(@RequestBody HelpModifyParam param);

    /**
     * 修改帮助
     *
     * @param param 帮助
     * @return 结果
     */
    @GetMapping("/help/updateHelp")
    public void updateHelp(Long id,HelpModifyParam param);


    /**
     * 删除帮助信息
     *
     * @param id 帮助主键
     * @return 结果
     */
    @DeleteMapping("/help/{id}")
    public void deleteHelpById(@PathVariable Long id);

    /**
     * 分页查询帮助列表
     * @param param
     * @return
     */
    @GetMapping("/help/getHelpPaging")
    Pagination<HelpDTO> getHelpPaging(HelpPagingParam param);
}
