package com.chelvc.cloud.vehicle.client;

import com.chelvc.cloud.vehicle.client.dto.MerchantAuthDTO;
import com.chelvc.cloud.vehicle.client.param.MerchantAuthModifyParam;
import com.chelvc.cloud.vehicle.client.param.MerchantAuthPagingParam;
import com.chelvc.framework.common.model.Pagination;
import org.springframework.cloud.openfeign.FeignClient;

/**
 * 商家认证业务接口
 *
 * @author liude
 * @data 2023/12/7
 */
@FeignClient("vehicle")
public interface MerchantAuthClient {

    /**
     * 新增商家认证
     *
     * @param param 新增参数
     * @return 主键
     */
    Long addMerchantAuth(MerchantAuthModifyParam param);

    /**
     * 修改商家认证
     *
     * @param id    主键
     * @param param 修改参数
     */
    void updateMerchantAuth(Long id, MerchantAuthModifyParam param);

    /**
     * 查询商家认证
     *
     * @param param 查询参数
     * @return 商家认证分页信息
     */
    Pagination<MerchantAuthDTO> getMerchantAuthPaging(MerchantAuthPagingParam param);

    /**
     * 查询商家认证信息
     * @return
     */
    MerchantAuthDTO queryById();

    /**
     * 商家认证是否通过
     * @param id 主键ID
     * @param state 0-拒绝 1-通过
     */
    void certificationAudit(Long id,String state,String message );
}
