package com.chelvc.cloud.vehicle.client;

import com.chelvc.cloud.vehicle.client.constant.ReserveStatus;
import com.chelvc.cloud.vehicle.client.dto.ReservationDTO;
import com.chelvc.cloud.vehicle.client.param.ReservationModifyParam;
import com.chelvc.cloud.vehicle.client.param.ReservationPagingParam;
import com.chelvc.cloud.vehicle.client.param.ReservationQueryParam;
import com.chelvc.framework.common.model.Pagination;
import org.springframework.cloud.openfeign.FeignClient;

import java.util.List;

/**
 * 预约业务接口
 *
 * @author Woody
 * @date 2023/7/17
 */
@FeignClient("vehicle")
public interface ReservationClient {
    /**
     * 新增预约信息
     *
     * @param merchantId 商家ID
     * @param param      预约参数
     */
    void addReservation(Long merchantId, ReservationModifyParam param);

    /**
     * 查询用户预约列表
     *
     * @param param 查询参数
     * @return 用户预约列表
     */
    List<ReservationDTO> listUserReservations(ReservationQueryParam param);

    /**
     * 取消预约
     *
     * @param id    预约记录逐渐主键
     */
    void deleteReservation(Long id);
    /**
     * 查询预约
     *
     * @param param 查询参数
     * @return 预约分页信息
     */
    Pagination<ReservationDTO> getReservationPaging(ReservationPagingParam param);

    /**
     * 查询商家被预约列表
     *
     * @param param 查询参数
     * @return 用户预约列表
     */
    List<ReservationDTO> listMerchantReservations(ReservationQueryParam param);

    /**
     * 更新预约单的状态
     * @param id 预约单ID
     * @param status 预约单的状态
     */
    void updateReservationsStatus(Long id, ReserveStatus status) ;


    /**
     * 预约详情
     * @param id
     * @return
     */
    ReservationDTO getDetail(Long id);


}
